@@ -1,12 +1,12 @@
 package Selenium::CanStartBinary::ProbePort;
-$Selenium::CanStartBinary::ProbePort::VERSION = '1.01'; # TRIAL
+$Selenium::CanStartBinary::ProbePort::VERSION = '1.19'; # TRIAL
 # ABSTRACT: Utility functions for finding open ports to eventually bind to
 use IO::Socket::INET;
 use Selenium::Waiter qw/wait_until/;
 
 require Exporter;
 our @ISA = qw/Exporter/;
-our @EXPORT_OK = qw/find_open_port_above probe_port/;
+our @EXPORT_OK = qw/find_open_port_above find_open_port probe_port/;
 
 sub find_open_port_above {
     my ($port) = @_;
@@ -24,6 +24,12 @@ sub find_open_port_above {
     return $free_port;
 }
 
+sub find_open_port {
+    my ($port) = @_;
+
+    probe_port($port) ? return 0 : return $port;
+}
+
 sub probe_port {
     my ($port) = @_;
 
@@ -46,7 +52,7 @@ Selenium::CanStartBinary::ProbePort - Utility functions for finding open ports t
 
 =head1 VERSION
 
-version 1.01
+version 1.19
 
 =head1 SEE ALSO
 
@@ -113,7 +119,7 @@ Aditya Ivaturi <ivaturi@gmail.com>
 
 Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
-Copyright (c) 2014-2016 Daniel Gempesaw
+Copyright (c) 2014-2017 Daniel Gempesaw
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
