@@ -1,5 +1,5 @@
 package Selenium::Firefox;
-$Selenium::Firefox::VERSION = '1.01'; # TRIAL
+$Selenium::Firefox::VERSION = '1.19'; # TRIAL
 # ABSTRACT: Use FirefoxDriver without a Selenium server
 use Moo;
 use Carp;
@@ -81,6 +81,11 @@ has 'firefox_binary' => (
     builder => 'firefox_path'
 );
 
+has '_execute_script_suffix' => (
+    is => 'lazy',
+    default => 'Gecko'
+);
+
 
 sub get_context {
     my $self = shift;
@@ -126,7 +131,7 @@ Selenium::Firefox - Use FirefoxDriver without a Selenium server
 
 =head1 VERSION
 
-version 1.01
+version 1.19
 
 =head1 SYNOPSIS
 
@@ -273,6 +278,11 @@ up to 20 seconds:
 
 See L<Selenium::CanStartBinary/startup_timeout> for more information.
 
+=head2 fixed_ports
+
+Optional: Throw instead of searching for additional ports; see
+L<Selenium::CanStartBinary/fixed_ports> for more info.
+
 =head1 METHODS
 
 =head2 shutdown_binary
@@ -424,7 +434,7 @@ Aditya Ivaturi <ivaturi@gmail.com>
 
 Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
-Copyright (c) 2014-2016 Daniel Gempesaw
+Copyright (c) 2014-2017 Daniel Gempesaw
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
