@@ -1,5 +1,5 @@
 package Selenium::Remote::Commands;
-$Selenium::Remote::Commands::VERSION = '1.01'; # TRIAL
+$Selenium::Remote::Commands::VERSION = '1.19'; # TRIAL
 # ABSTRACT: Implement commands for Selenium::Remote::Driver
 
 use Moo;
@@ -406,6 +406,18 @@ has '_cmds' => (
                 'no_content_success' => 0
             },
 
+            # geckodriver workarounds
+            'executeScriptGecko' => {
+                'method'             => 'POST',
+                'url'                => 'session/:sessionId/execute/sync',
+                'no_content_success' => 0
+            },
+            'executeAsyncScriptGecko' => {
+                'method'             => 'POST',
+                'url'                => 'session/:sessionId/execute/async',
+                'no_content_success' => 0
+            },
+
             # /session/:sessionId/local_storage
             # /session/:sessionId/local_storage/key/:key
             # /session/:sessionId/local_storage/size
@@ -472,7 +484,7 @@ Selenium::Remote::Commands - Implement commands for Selenium::Remote::Driver
 
 =head1 VERSION
 
-version 1.01
+version 1.19
 
 =head1 SEE ALSO
 
@@ -539,7 +551,7 @@ Aditya Ivaturi <ivaturi@gmail.com>
 
 Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
-Copyright (c) 2014-2016 Daniel Gempesaw
+Copyright (c) 2014-2017 Daniel Gempesaw
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
